#!/bin/bash

MOUNTPOINT=`mktemp -d`

if [ -e "$( dirname $0 )/sh/basefunctions.sh" ]; then
        BOOTCD_BASE_DIR=$( cd $( dirname $0 ) && pwd )
else
        BOOTCD_BASE_DIR=/usr/share/apps/tuxum-bootcd/
fi

. ${BOOTCD_BASE_DIR}/sh/basefunctions.sh

message "Base dir at ${BOOTCD_BASE_DIR}"

if [ ! -e bootcd.config ]; then
	error "ERROR: bootcd.config does not exist at current dir!"
	echo
	echo "Look at the documentation for help on how to create one"
	echo
	exit 1
fi

if [ "$1" == "" ]; then
  error "I need the device where the data should be copied, for example /dev/sdb1"
  exit 1
fi

. ${BOOTCD_BASE_DIR}/globalconfig.bootcd

# use a given config file or default named bootcd.config
. ./bootcd.config


ISO=${BOOTCD_TEMP}/iso/

if [ ! -e "${ISO}" ]; then
  error "Iso directory ${ISO} does not exists. Did you executed tuxum-bootcd.sh?"
  exit 3
fi

DRIVE=$( echo $1 | sed "s/[0-9]*//g" )

message "Verifying $1 is not mounted..."
MOUNTED=`mount | grep -w "$1" | awk '{print $1}'`

if [ -n "$MOUNTED" ]
then
	message "Trying  to umount $1..."
	for i in $MOUNTED
	do
		umount $i
		if ! [ "$?" == "0" ]
		then
			echo "Cannot umount. Exiting."
			exit 1
		fi
	done
fi

message "Mounting..."
mount -o quiet $1 $MOUNTPOINT
if [ "$?" != "0" ]; then
  error "Mounting $1 at $MOUNTPOINT"
  exit 2
fi

message "Cleaning..."
for i in ${ISO}/*
do
	rm -rf $MOUNTPOINT/`basename $i`
done

for i in .tuxum_bootcd syslinux.cfg isolinux.cfg stage2.squashfs ldlinux.sys boot
do
	rm -rf $MOUNTPOINT/$i
done

message "Copying..."
cp ${ISO}/* ${ISO}/.tuxum_bootcd $MOUNTPOINT -a

if [ -e $MOUNTPOINT/isolinux.cfg ]; then
	message "Install syslinux..."
	cp $MOUNTPOINT/isolinux.cfg $MOUNTPOINT/syslinux.cfg
	syslinux $1
else
	message "Install grub..."
	grub-install --root-directory=$MOUNTPOINT --no-floppy ${DRIVE} 2> /dev/null > /dev/null
	sed -i "s/cd/hd0,0/g" $MOUNTPOINT/boot/grub/menu.lst
fi
message "Umount..."
umount $1

message_ok "You can now use your PenDrive as a Boot CD"
exit 0
