#!/bin/bash

MODULE_LIST=$1
KERNELVER=$2
SOURCE=$3
DEST=$4

if [ -z "$DEST" ] || [ -n "$5" ]
then
	echo "Usage: cp_modules <module list file> <kernel version> <source directory> <destination directory>"
	echo "Example: cp_modules /tmp/files.kernel 2.6.24 /source /tmp/target"
	echo "  will install modules listed on file /tmp/files.kernel"
	echo "  from /source/lib/modules/2.6.24 to /tmp/target/lib/modules/2.6.24"
	exit 1
fi

n=0

function cp_module {
        mod=$( echo "$1" | sed 's/.ko$//g' )

        if echo $1 | grep snd > /dev/null ; then # ignore snd modules
                        return 0
        fi

        # already copied, fast skip
        if [ -e $DEST/lib/modules/${KERNELVER}/kernel/$mod.ko ]; then
                return 0
        fi

        orig=$( cat $FINDCACHE | grep $( echo $mod | sed "s/-/\[-_\]/g" ).ko )
        cp $orig $DEST/lib/modules/${KERNELVER}/kernel 2>/dev/null
        if [ "$?" != "0" ]; then
                if [ -z "$orig" ]; then
                        echo 'cat $FINDCACHE | grep $( echo $mod | sed "s/-/\[-_\]/g" ).ko'
                        echo "Module '$1' Does not exists at /lib/modules/${KERNEL_VERSION}" >&2
                        ERROR_CODE=4
                        return 4
                else
                        echo "Copying module '$1' from '$orig' to '$DEST/lib/modules/${KERNEL_VERSION}/kernel'" >&2
                        ERROR_CODE=5
                        return 5
                fi
        fi
        #modinfo -k ${KERNEL_VERSION} $1 | grep depends | awk '{ print $2 }' | sed "s/,/ /g"
        for dep in $( modinfo -b $SOURCE -k ${KERNELVER} $mod | grep ^depends: | awk '{ print $2 }' | sed "s/,/ /g" ); do
                cp_module $dep
        done

        n=$[ $n + 1 ]
}

function cp_module_dir {
        for ko in $( cat $FINDCACHE | grep "$1" | grep '.ko$' ); do
                cp_module $( basename $ko )
        done
}

find $SOURCE/lib/modules/$KERNELVER > findcache
FINDCACHE=$( pwd )/findcache

# prepare for kernel modules
mkdir -p $DEST/lib/modules/${KERNELVER}/kernel
for i in $( cat "${MODULE_LIST}" ); do
        echo "Copy module $i"
        if ( echo $i | grep -v "^#" > /dev/null ) && [ ! -z "$i" ]; then
                if echo $i | grep '/$' > /dev/null; then
                        cp_module_dir $i
                else
                        cp_module $i
                fi
        fi
done

touch $DEST/lib/modules/${KERNELVER}/modules.order
touch $DEST/lib/modules/${KERNELVER}/modules.builtin

#rm $FINDCACHE

if [ "$ERROR_CODE" != '0' ];then
        exit $ERROR_CODE
fi
